AdvancedDataTableSource<T> class abstract

Inheritance

Constructors

AdvancedDataTableSource()

Properties

forceRemoteReload ↔ bool
Set this to true to indicate that a reload should happen even if the page details did not change
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasListeners → bool
Whether any listeners are currently registered.
no setterinherited
initialRequestCompleted → bool
True if there is any data loaded in this source
no setter
isRowCountApproximate → bool
Called to establish if rowCount is a precise number or might be an over-estimate. If this returns true (i.e. the count is approximate), and then later the exact number becomes available, then call notifyListeners.
no setteroverride
lastDetails ↔ RemoteDataSourceDetails<T>?
Last loaded data from the remote data source
getter/setter pair
nextStartIndex ↔ int?
The index for the next page to start
getter/setter pair
rowCount → int
Called to obtain the number of rows to tell the user are available.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
selectedRowCount → int
Called to obtain the number of rows that are currently selected.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
inherited
getNextPage(NextPageRequest pageRequest) → Future<RemoteDataSourceDetails<T>>
Called by the base data source class to load data, implement your backend call in this function
getRow(int index) → DataRow?
Called to obtain the data about a particular row.
inherited
loadNextPage(int pageSize, int offset, int? columnSortIndex, {bool? sortAscending}) → Future<int>
Called by the advanced datatable controll to trigger a page load
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
requireRemoteReload() → bool
Override this function to ensure a remote reload is done If you override this function ensure to reset the state once a reload has happend Consider the reload as done once this funciton is called
setNextView({int startIndex = 0}) → void
Sets the next view state for the table, this can be used to go back to any start view index (page), will trigger a reload
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited