RemoteDataSourceDetails<T> class

Constructors

RemoteDataSourceDetails(int totalRows, List<T> rows, {int? filteredRows})

Properties

filteredRows → int?
The total amount of rows after a filter was applied
final
hashCode → int
The hash code for this object.
no setterinherited
rows → List<T>
The data retured by the remote data source
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
totalRows → int
All avalible rows in the remote data source without any filter
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited